local Tinykos, self = Tinykos, Tinykos

local AceConfigDialog = LibStub("AceConfigDialog-3.0")

local L = LibStub("AceLocale-3.0"):GetLocale("TinyKoS")


local function getListArgs()
	
	local args = {
		NewEntry = {
			order = 1,
			name = L["New entry"],
			desc = L["Add new name to KoS-list"],
			type = 'input',
			set = function(info,val) self:AddToList(val) self:buildOptions() end,
			get = function() return "" end,
		},
	}
	
	for k,v in pairs(self.db.realm.watchlist) do
		args[k] = {
			name = k,
			desc = string.format("Entry for %s",k),
			type = 'group',
			args = {
				reason = {
					name = L["Reason"],
					desc = L["The Reason why this player is on KoS"],
					type = 'input',
					get = function() return self.db.realm.watchlist[k].reason end,
					set = function(info, val)
						self.db.realm.watchlist[k].reason = val
					end,
				},
				remove = {
				name = L["Remove"],
				desc = L["Remove this player from the KoS-List"],
				type = 'execute',
				func = function() 
					self.db.realm.watchlist[k] = nil
					self:buildOptions()
				end,	  
				},
			},
		}
	end
	
	return args
end

function Tinykos:buildOptions()
	if not self.options then
		self.options = {
		name = "TinyKoS",
		desc = L["configure TinyKoS"],
		type = 'group',
		args = {
			general = {
				name = L["General"],
				desc = L["General options"],
				type = 'group',
				args = {
					warningInterval = {
						name = L["Warning Interval"],
						desc = L["Minimum time to pass between two warnings for the same player"],
						type = 'input',
						get = function() return "" .. self.db.profile.warningInterval end,
						set = function(info,val)
								if tonumber(val) then
									self.db.profile.warningInterval = tonumber(val)
								end
							end,
					}
				}
			},
			--	"friendly" -- , if the zone is controlled by the faction the player belongs to.
			--	"contested" -- if the zone is contested (PvP server only)
			--	"hostile" -- , if the zone is controlled by the opposing faction.
			--	"sanctuary" -- , if the zone is a sanctuary and does not allow pvp combat (2.0.x).
			--	"combat" -- , if it is a combat zone where players are automatically flagged for PvP combat (3.0.x). Currently applies only to the Wintergrasp zone.
			--	nil -- , if the zone is none of the above. Happens inside instances, including battlegrounds, and on PvE servers when the zone would otherwise be "contested". 
			show_in = {
				name = L["Zone types"],
				desc = L["Check in which zone types warnings should be shown"],
				type = 'group',
				args = {
					friendly = {
						name = L["Friendly"],
						type = 'toggle',
						get = function() return self.db.profile.hide.friendly end,
						set = function(info,val) self.db.profile.hide.friendly = val end,
					},
					contested = {
						name = L["Contested (only PvP-Servers)"],
						type = 'toggle',
						get = function() return self.db.profile.hide.contested end,
						set = function(info,val) self.db.profile.hide.contested = val end,
					
					},
					hostile = {
						name = L["Hostile"],
						type = 'toggle',
						get = function() return self.db.profile.hide.hostile end,
						set = function(info,val) self.db.profile.hide.hostile = val end,
					},
					sanctuary = {
						name = L["Sanctuary (Shattrath, Dalaran)"],
						type = 'toggle',
						get = function() return self.db.profile.hide.sanctuary end,
						set = function(info,val) self.db.profile.hide.sanctuary = val end,
					},
					combat = {
						name = L["Combat (Wintergrasp)"],
						type = 'toggle',
						get = function() return self.db.profile.hide.combat end,
						set = function(info,val) self.db.profile.hide.combat = val end,
					},
					other = {
						name = L["Other (Instances, Battlegrounds, ...)"],
						type = 'toggle',
						get = function() return self.db.profile.hide._nil end,
						set = function(info,val) self.db.profile.hide._nil = val end,
					},
					
				},
			},
			sink = self:GetSinkAce3OptionsDataTable(),
			list = {
				name = L["List"],
				desc = L["Teh List"],
				type = 'group',
				args = getListArgs(),
			},
			profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db),
		},
	}
	end
	
	self.options.args.list.args = getListArgs()
end

function Tinykos:ShowConfig()
	AceConfigDialog:Open("TinyKoS")
end

function Tinykos:InitOptions()
	self:buildOptions()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("TinyKoS", self.options, "tinykos")
	self.OpenMenu = self.ShowConfig
	AceConfigDialog:AddToBlizOptions("TinyKoS", "TinyKoS")
end
